# duckcuts

Duckcuts is a TUI (Terminal User Interface) application for Unix-like and MacOS computers that is meant to help you learn shortcuts of various programs, with main focus on programs that live in the terminal.

## Install via pip

```sh
pip install duckcuts
```

## Run

```sh
duckcuts
```

## FAQ

**What operating systems are supported?**

_The application is tested on MacOS Sonoma but should run on most modern Unix(-like) systems with a relatively new version of Python (3.8+)._

**Why does the program look really weird in my terminal?**

_You are probably using a very non-modern terminal, like terminal.app on MacOS. Try using iTerm2 or Alacritty instead._

**How do I add my own shortcuts?**

_In the about screen, which can be viewed by pressing A, there is the path to the folder where you can add your own JSON files with shortcuts which will be loaded on program startup._

**How do I remove shortcuts?**

_You can delete them from the JSON files._
